From 340f2a6596aeb29a945e9ff6928f918ac2cf8327 Mon Sep 17 00:00:00 2001
From: John Naylor <john.naylor@2ndquadrant.com>
Date: Wed, 10 Mar 2021 09:44:18 -0400
Subject: [PATCH v1] Get rid of <foreignphrase> tags in the docs
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

We italicize some, but not all, instances of "per se", "pro forma", and
"ad hoc". These phrases are widespread in formal registers of English,
so it"s debatable whether they even qualify as foreign. We could instead
try to be more consistent in the use of <foreignphrase>, but that"s
difficult to enforce, so let"s just remove the tags for those words.

The one case that seems to deserve the tag is "voilà". Instead of keeping
just one instance of the tag, change that to a more standard phrase.
---
 doc/src/sgml/ddl.sgml             | 4 ++--
 doc/src/sgml/ref/create_role.sgml | 5 ++---
 doc/src/sgml/rules.sgml           | 2 +-
 doc/src/sgml/typeconv.sgml        | 5 ++---
 4 files changed, 7 insertions(+), 9 deletions(-)

diff --git a/doc/src/sgml/ddl.sgml b/doc/src/sgml/ddl.sgml
index 1e9a4625cc..422c1180ba 100644
--- a/doc/src/sgml/ddl.sgml
+++ b/doc/src/sgml/ddl.sgml
@@ -2763,8 +2763,8 @@ CREATE SCHEMA myschema;
 <synopsis>
 <replaceable>database</replaceable><literal>.</literal><replaceable>schema</replaceable><literal>.</literal><replaceable>table</replaceable>
 </synopsis>
-    can be used too, but at present this is just for <foreignphrase>pro
-    forma</foreignphrase> compliance with the SQL standard.  If you write a database name,
+    can be used too, but at present this is just for pro forma
+    compliance with the SQL standard.  If you write a database name,
     it must be the same as the database you are connected to.
    </para>
 
diff --git a/doc/src/sgml/ref/create_role.sgml b/doc/src/sgml/ref/create_role.sgml
index 73b30d7b23..819ae89f38 100644
--- a/doc/src/sgml/ref/create_role.sgml
+++ b/doc/src/sgml/ref/create_role.sgml
@@ -358,9 +358,8 @@ in sync when changing the above synopsis!
 
   <para>
    The <literal>VALID UNTIL</literal> clause defines an expiration time for a
-   password only, not for the role <foreignphrase>per se</foreignphrase>.  In
-   particular, the expiration time is not enforced when logging in using
-   a non-password-based authentication method.
+   password only, not for the role per se.  In particular, the expiration time
+   is not enforced when logging in using a non-password-based authentication method.
   </para>
 
   <para>
diff --git a/doc/src/sgml/rules.sgml b/doc/src/sgml/rules.sgml
index aa172d102b..3dad302c80 100644
--- a/doc/src/sgml/rules.sgml
+++ b/doc/src/sgml/rules.sgml
@@ -1941,7 +1941,7 @@ DELETE FROM shoelace WHERE EXISTS
              WHERE sl_name = shoelace.sl_name);
 </programlisting>
 
-    <foreignphrase>Voil&agrave;</foreignphrase>:
+    The results are:
 
 <programlisting>
 SELECT * FROM shoelace;
diff --git a/doc/src/sgml/typeconv.sgml b/doc/src/sgml/typeconv.sgml
index 810b0cb557..ebd70df689 100644
--- a/doc/src/sgml/typeconv.sgml
+++ b/doc/src/sgml/typeconv.sgml
@@ -40,9 +40,8 @@ has an associated data type which determines its behavior and allowed usage.
 <productname>PostgreSQL</productname> has an extensible type system that is
 more general and flexible than other <acronym>SQL</acronym> implementations.
 Hence, most type conversion behavior in <productname>PostgreSQL</productname>
-is governed by general rules rather than by <foreignphrase>ad hoc</foreignphrase>
-heuristics.  This allows the use of mixed-type expressions even with
-user-defined types.
+is governed by general rules rather than by ad hoc heuristics.  This allows
+the use of mixed-type expressions even with user-defined types.
 </para>
 
 <para>
-- 
2.22.0

